@@ -237,10 +237,7 @@ impl ResourcePathsIter<'_> {
     self.current_path = None;
 
     let pattern = match &mut self.pattern_iter {
-      PatternIter::Slice(iter) => match iter.next() {
-        Some(pattern) => pattern,
-        None => return None,
-      },
+      PatternIter::Slice(iter) => iter.next()?,
       PatternIter::Map(iter) => match iter.next() {
         Some((pattern, dest)) => {
           self.current_pattern = Some(pattern.clone());
