@@ -244,6 +244,11 @@ impl<R: Runtime> fmt::Debug for AppManager<R> {
   }
 }
 
+pub(crate) enum EmitPayload<'a, S: Serialize> {
+  Serialize(&'a S),
+  Str(String),
+}
+
 impl<R: Runtime> AppManager<R> {
   #[allow(clippy::too_many_arguments, clippy::type_complexity)]
   pub(crate) fn with_handlers(
@@ -399,27 +404,23 @@ impl<R: Runtime> AppManager<R> {
     let mut asset_path = AssetKey::from(path.as_str());
 
     let asset_response = assets
-      .get(&path.as_str().into())
+      .get(&asset_path)
       .or_else(|| {
         log::debug!("Asset `{path}` not found; fallback to {path}.html");
-        let fallback = format!("{}.html", path.as_str()).into();
+        let fallback = format!("{path}.html").into();
         let asset = assets.get(&fallback);
         asset_path = fallback;
         asset
       })
       .or_else(|| {
-        log::debug!(
-          "Asset `{}` not found; fallback to {}/index.html",
-          path,
-          path
-        );
-        let fallback = format!("{}/index.html", path.as_str()).into();
+        log::debug!("Asset `{path}` not found; fallback to {path}/index.html",);
+        let fallback = format!("{path}/index.html").into();
         let asset = assets.get(&fallback);
         asset_path = fallback;
         asset
       })
       .or_else(|| {
-        log::debug!("Asset `{}` not found; fallback to index.html", path);
+        log::debug!("Asset `{path}` not found; fallback to index.html");
         let fallback = AssetKey::from("index.html");
         let asset = assets.get(&fallback);
         asset_path = fallback;
@@ -452,13 +453,13 @@ impl<R: Runtime> AppManager<R> {
             csp_header.replace(Csp::DirectiveMap(csp_map).to_string());
           }
 
-          asset.as_bytes().to_vec()
+          asset.into_bytes()
         } else {
           asset
         };
         let mime_type = tauri_utils::mime_type::MimeType::parse(&final_data, &path);
         Ok(Asset {
-          bytes: final_data.to_vec(),
+          bytes: final_data,
           mime_type,
           csp_header,
         })
@@ -540,21 +541,18 @@ impl<R: Runtime> AppManager<R> {
   pub(crate) fn emit<S: Serialize>(
     &self,
     event: EventName<&str>,
-    payload: &S,
+    payload: EmitPayload<'_, S>,
   ) -> crate::Result<()> {
     #[cfg(feature = "tracing")]
     let _span = tracing::debug_span!("emit::run").entered();
-    let emit_args = EmitArgs::new(event, &payload)?;
+    let emit_args = match payload {
+      EmitPayload::Serialize(payload) => EmitArgs::new(event, payload)?,
+      EmitPayload::Str(payload) => EmitArgs::new_str(event, payload)?,
+    };
 
     let listeners = self.listeners();
-    let webviews = self
-      .webview
-      .webviews_lock()
-      .values()
-      .cloned()
-      .collect::<Vec<_>>();
 
-    listeners.emit_js(webviews.iter(), &emit_args)?;
+    listeners.emit_js(self.webview.webviews_lock().values(), &emit_args)?;
     listeners.emit(emit_args)?;
 
     Ok(())
@@ -567,7 +565,7 @@ impl<R: Runtime> AppManager<R> {
   pub(crate) fn emit_filter<S, F>(
     &self,
     event: EventName<&str>,
-    payload: S,
+    payload: EmitPayload<'_, S>,
     filter: F,
   ) -> crate::Result<()>
   where
@@ -576,7 +574,10 @@ impl<R: Runtime> AppManager<R> {
   {
     #[cfg(feature = "tracing")]
     let _span = tracing::debug_span!("emit::run").entered();
-    let emit_args = EmitArgs::new(event, &payload)?;
+    let emit_args = match payload {
+      EmitPayload::Serialize(payload) => EmitArgs::new(event, payload)?,
+      EmitPayload::Str(payload) => EmitArgs::new_str(event, payload)?,
+    };
 
     let listeners = self.listeners();
 
@@ -599,7 +600,7 @@ impl<R: Runtime> AppManager<R> {
     &self,
     target: I,
     event: EventName<&str>,
-    payload: &S,
+    payload: EmitPayload<'_, S>,
   ) -> crate::Result<()>
   where
     I: Into<EventTarget>,
