@@ -113,8 +113,26 @@ export interface TrayIconOptions {
    * Use the icon as a [template](https://developer.apple.com/documentation/appkit/nsimage/1520017-template?language=objc). **macOS only**.
    */
   iconAsTemplate?: boolean
-  /** Whether to show the tray menu on left click or not, default is `true`. **macOS only**. */
+  /**
+   * Whether to show the tray menu on left click or not, default is `true`.
+   *
+   * #### Platform-specific:
+   *
+   * - **Linux**: Unsupported.
+   *
+   * @deprecated use {@linkcode TrayIconOptions.showMenuOnLeftClick} instead.
+   */
   menuOnLeftClick?: boolean
+  /**
+   * Whether to show the tray menu on left click or not, default is `true`.
+   *
+   * #### Platform-specific:
+   *
+   * - **Linux**: Unsupported.
+   *
+   * @since 2.2.0
+   */
+  showMenuOnLeftClick?: boolean
   /** A handler for an event on the tray icon. */
   action?: (event: TrayIconEvent) => void
 }
@@ -278,13 +296,37 @@ export class TrayIcon extends Resource {
     })
   }
 
-  /** Disable or enable showing the tray menu on left click. **macOS only**. */
+  /**
+   *  Disable or enable showing the tray menu on left click.
+   *
+   * #### Platform-specific:
+   *
+   * - **Linux**: Unsupported.
+   *
+   * @deprecated use {@linkcode TrayIcon.setShowMenuOnLeftClick} instead.
+   */
   async setMenuOnLeftClick(onLeft: boolean): Promise<void> {
     return invoke('plugin:tray|set_show_menu_on_left_click', {
       rid: this.rid,
       onLeft
     })
   }
+
+  /**
+   *  Disable or enable showing the tray menu on left click.
+   *
+   * #### Platform-specific:
+   *
+   * - **Linux**: Unsupported.
+   *
+   * @since 2.2.0
+   */
+  async setShowMenuOnLeftClick(onLeft: boolean): Promise<void> {
+    return invoke('plugin:tray|set_show_menu_on_left_click', {
+      rid: this.rid,
+      onLeft
+    })
+  }
 }
 
 function mapEvent(e: RustTrayIconEvent): TrayIconEvent {
